@@ -539,6 +539,7 @@ window_create (void)
 		}
 	}
 
+
 	/* add buttons */
 	if (gx.do_buttons) {
 
@@ -552,7 +553,10 @@ window_create (void)
 
 		while (button != NULL) {
 
-			if (g_str_has_prefix (button->label, "GTK_STOCK_")) {
+			if (strcmp (button->label, "okay") == 0) {
+				btn = gtk_button_new_from_stock ("gtk-ok");
+			}
+			else if (g_str_has_prefix (button->label, "GTK_STOCK_")) {
 				gchar *s;
 				gchar *p;
 				p = g_ascii_strdown (button->label + 10, -1);
@@ -582,6 +586,7 @@ window_create (void)
 		}
 	}
 
+
 	/* window geometry */
 
 	max_w = gdk_screen_width () * 0.7;
